# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.11.0~02f06ba',
    built_at='2024-10-01 05:26:19Z',
    sha='02f06bac8b3d74154d8d3ef2a56841bc80a88293',
    branch='HEAD',
    tag='v4.11.0',
)
